% This file declares the physical parameters that stay constant throughout
% the simulation, in a addition to some empty matrixes to contain parameter
% history.

%*************************************************************************
% Physical constants 
mu_0 = 4*pi*10^-7;

%*************************************************************************
% Physical parameters specific to the machine, consult drawings of the
% machine

B_r = 1.20;             %PM remanence

l = 70;                 %Machine length (mm)
D_ro = 179;             %Rotor outer diameter (mm)
D_ri = 164;             %Rotor inner diameter (mm)
D_si = 200;             %Stator inner diameter (mm)
l_gmin = 0.5;           %Min. gap i el.mag parts (mm)

e = (D_si-(D_ro+2*l_gmin))/2;   %Eccentricity

l_gmaks = 2*e+l_gmin;   %Max. gap in el.mag. parts (mm)

n = 16;                 %Number of airgaps (poles)
rho = (2*pi)/n;         %Distance between poles (radianer)

k_c = 1.8;              %The Carter coefficient, see report sec.

A_g = l*39.59/k_c;      %Area luftgap (mm2)
A_m = l*20.4;           %Area magnet  (mm2)
A_mg= l*21.54;          %Area magnetgap (mm2)
A_l = 1.2*l*19;         %Area leak.gap (mm2) Factor 0.2 accounting for fringing on 108mm
l_m = 24.9;             %Length magnet (mm)
l_mg = 25;              %Length magnetgap (mm)
l_l = 4;                %Length leakgap(mm)


%*************************************************************************
% Coils are set up with in a matrix with [current,turns]
Imax = 10;
N= 300;

C = zeros(8,2);     
MMF = zeros(8,1);

%*************************************************************************
%Permanent magnets:

Phir = B_r*A_m/1000000;   %Every permanent magnet considered equal

%*************************************************************************
% The reluctance in the magnet gap is constant.
Rm = 1000*l_mg/(mu_0*A_mg);

% Stator unit reluctance with leakage gap:

Rl = 1000*l_l/(mu_0*A_l);     

Rsstandard = Rl*Rm/(Rl+Rm);  

% Reluctance with no leakage gap: Rl is replaced by a full gap 1.5 the
% area of the magnet gap.

%Rl = 1.5*Rm;

Rs = Rl*Rm/(Rl+Rm);  


