% This is the main frame for the script

clc;

% What calculations do you want to run? 
% 1 - Self inductance of one coil
% 2 - Mutual inductance between one coil and the other coils
% 3 - PM linkage
% 4 - Torque (Heavy calculation)
% 5 - Switch current scheme only (Used to find optimal leading angle)

calc = 4;

% What kind of current scheme do you want to run?
% 1 - Const current
% 2 - Individual control
% 3 - Three phase
% 4 - Eight phase

curr = 4;

% Current leading factor to rotor position. (For sinusoidal currents)

psi = 70*pi/180;

% Sets resolution of the calculation. High number, heavier calculation.

Res=360;        


%*************************************************************************

% The calculation loops

%*************************************************************************
%Preallocated storage vectors, without overwriting earlier, different
%calculations.

switch calc
    case 1
        SelfInductance = zeros(Res,1);
    
    case 2 
        MutualInductance = zeros(Res,7);
        H = zeros(7,7);
    
    case 3    
        PMContribution = zeros(Res,1);
    
    case 4    
        SelfInductance = zeros(Res,1);
        MutualInductance = zeros(Res,7);
        H = zeros(7,7);
        PMContribution = zeros(Res,1);
        PMScf = zeros(Res,1);
        Zpast = zeros(Res,1);
        HistoricMMF = zeros(Res,8);
        HistoricCoil = zeros(Res,8);
        
    case 5
        HistoricMMF = zeros(Res,8);
        HistoricCoil = zeros(Res,8);
    otherwise
        disp('Wrong choice')
end

%*************************************************************************
%Runs the calculations

run ConstParam

for j=1:Res

    theta = ((2*pi*(j-1))/Res)+pi;     %Moves rotor     
    teller=j;
    
    run Param                     %Sets parameters at new rotor position
    
    switch calc
        case 1          
            run Selfinductance           
            SelfInductance(j)=(C(1,2))^2./(Z(1,1)); %
           
        case 2        
            run Mutualinductance
            Rematrise = [1/Rg(3),1/Rg(5),1/Rg(7),1/Rg(9),1/Rg(11),1/Rg(13),1/Rg(15)];          
            for k=1:7         
                H(k,k)=(NI(2)-NI(2*k+2));       %MMF across air gap          
            end
            MutualInductance(j,:)=abs(N/10).*Rematrise*H;
    
        case 3     
            run PMlinkage           
            PMContribution(j)= (-NI(1))./Rg(1);

        case 4        
            run Selfinductance  
            SelfInductance(j)=(C(1,2))^2./(Z(1,1));
            Zpast(j) = Z(1,1);

            run Mutualinductance
            Rematrise = [1/Rg(3),1/Rg(5),1/Rg(7),1/Rg(9),1/Rg(11),1/Rg(13),1/Rg(15)];          
            for k=1:7         
                H(k,k)=(NI(2)-NI(2*k+2));       %MMF across air gap         
            end
            MutualInductance(j,:)=abs((N/10)).*Rematrise*H;

            run PMlinkage    
            
            PMContribution(j)= (-NI(1))./Rg(1);
            
            K_s = (Rg(1)+(Rg(2)*Rg(16)/(Rg(2)+Rg(16)))+Rsstandard)/...
                  (Rg(1)+(Rg(2)*Rg(16)/(Rg(2)+Rg(16)))+Rs);
            
            PMScf(j) = (-NI(1))./Rg(1)*K_s;
    end
end
 
 if ((calc == 4) || (calc == 5))   
      run Torque
 end
 
 
 