%Setting the parameters that vary with rotor position. The different
%current control schemes are also defined here.
%*************************************************************************

switch curr
    
% Setting constant currents, case 1
    case 1
        for l=1:8
            C(l,1)= Imax;
        end
        
   
% Setting the currents for the individual control, case 2
    case 2
        if (theta<2*pi) && (theta>=1.5*pi)
            C(1,1) = Imax;
        elseif (theta<2.5*pi) && (theta>=2*pi)
            C(1,1) = -Imax;
        else   
            C(1,1) = 0;
        end

        if (theta<2.25*pi) && (theta>=1.75*pi)
            C(2,1) = Imax;
        elseif (theta<2.75*pi) && (theta>=2.25*pi)
            C(2,1) = -Imax;
        else   
            C(2,1) = 0;
        end

        if (theta<2.5*pi) && (theta>=2*pi)
            C(3,1) = Imax;
        elseif (theta<3*pi) && (theta>=2.5*pi)
            C(3,1) = -Imax;
        else   
            C(3,1) = 0;
        end

        if (theta<2.75*pi) && (theta>=2.25*pi)
            C(4,1) = Imax;
        elseif (theta<1.25*pi) || (theta>=2.75*pi)
            C(4,1) = -Imax;
        else   
            C(4,1) = 0;
        end

        if (theta<3*pi) && (theta>=2.5*pi)
            C(5,1) = Imax;
        elseif (theta<1.5*pi) && (theta>=pi)
            C(5,1) = -Imax;
        else   
            C(5,1) = 0;
        end

        if (theta >=2.75*pi) || (theta<1.25*pi)
            C(6,1) = Imax;
        elseif (theta<1.75*pi) && (theta>=1.25*pi)
            C(6,1) = -Imax;
        else   
            C(6,1) = 0;
        end

        if (theta<1.5*pi) && (theta>=pi)
            C(7,1) = Imax;
        elseif (theta<2*pi) && (theta>=1.5*pi)
            C(7,1) = -Imax;
        else   
            C(7,1) = 0;
        end

        if (theta<1.75*pi) && (theta>=1.25*pi)
            C(8,1) = Imax;
        elseif (theta<2.25*pi) && (theta>=1.75*pi)
            C(8,1) = -Imax;
        else   
            C(8,1) = 0;
        end

% Setting three phase currents, case 3

% All phases get two full coils.
% The remaining to are split: (2/3 theta + 1/3 b) and (2/3 c + 1/3 b)
    case 3            
        C(1,1) = Imax*cos(theta+psi);                                  % a
        C(2,1) = Imax*cos(theta+psi);                                  % a 
        C(3,1) = Imax*(2*cos(theta+psi)+cos(theta+psi-2/3*pi))/3;      % a + b
        C(4,1) = Imax*cos(theta+psi-2/3*pi);                           % b
        C(5,1) = Imax*cos(theta+psi-2/3*pi);                           % b
        C(6,1) = Imax*(cos(theta+psi-2/3*pi)+2*cos(theta+psi-4/3*pi))/3;% b + c
        C(7,1) = Imax*cos(theta+psi-4/3*pi);                           % c
        C(8,1) = Imax*cos(theta+psi-4/3*pi);                           % c


%Setting the eight phase currents, case 4
    case 4        
         C(1,1) = Imax*cos(theta+psi);                          
         C(2,1) = Imax*cos(theta+psi-(1*pi/4));                   
         C(3,1) = Imax*cos(theta+psi-(2*pi/4));    
         C(4,1) = Imax*cos(theta+psi-(3*pi/4));                
         C(5,1) = Imax*cos(theta+psi-(4*pi/4));                        
         C(6,1) = Imax*cos(theta+psi-(5*pi/4));   
         C(7,1) = Imax*cos(theta+psi-(6*pi/4));                       
         C(8,1) = Imax*cos(theta+psi-(7*pi/4));                         
end

% ************************************************************************
% Storing the current values for use in the torque-calculations
for l=1:8
   
    C(l,2)=N; 
    MMF(l)=C(l,1)*C(l,2);
    
    HistoricCoil(teller,l)=C(l,1);
    HistoricMMF(teller,l) =MMF(l);
end

%*************************************************************************
% Varying reluctances:

%theta=0;                    %Rotor position (radians) (Normally set outside)

Rg = [1000/(mu_0*A_g).*(e*(1-cos(theta))+0.5);            % Reluctance air gap  1
      1000/(mu_0*A_g).*(e*(1-cos(theta-rho))+0.5);        %          =          2    
      1000/(mu_0*A_g).*(e*(1-cos(theta-2*rho))+0.5);      %          =          3       
      1000/(mu_0*A_g).*(e*(1-cos(theta-3*rho))+0.5);      %          =          4 
      1000/(mu_0*A_g).*(e*(1-cos(theta-4*rho))+0.5);      %          =          5 
      1000/(mu_0*A_g).*(e*(1-cos(theta-5*rho))+0.5);      %          =          6 
      1000/(mu_0*A_g).*(e*(1-cos(theta-6*rho))+0.5);      %          =          7
      1000/(mu_0*A_g).*(e*(1-cos(theta-7*rho))+0.5);      %          =          8 
      1000/(mu_0*A_g).*(e*(1-cos(theta-8*rho))+0.5);      %          =          9 
      1000/(mu_0*A_g).*(e*(1-cos(theta-9*rho))+0.5);      %          =         10 
      1000/(mu_0*A_g).*(e*(1-cos(theta-10*rho))+0.5);     %          =         11
      1000/(mu_0*A_g).*(e*(1-cos(theta-11*rho))+0.5);     %          =         12
      1000/(mu_0*A_g).*(e*(1-cos(theta-12*rho))+0.5);     %          =         13
      1000/(mu_0*A_g).*(e*(1-cos(theta-13*rho))+0.5);     %          =         14
      1000/(mu_0*A_g).*(e*(1-cos(theta-14*rho))+0.5);     %          =         15
      1000/(mu_0*A_g).*(e*(1-cos(theta-15*rho))+0.5)];    %          =         16  
  
  
  